@@ -94,9 +94,17 @@ LockScreen::LockScreen() :
     if (LsWidget::isPortrait()){
         m_Scene.setSceneRect(0, 0, 480, 800);
         m_View->setFixedSize(480, 800);
+        if (m_LabelBackground){
+            m_LabelBackground->setFixedSize(480, 800);
+            m_Proxy->setPos(0,0);
+        }
     }else{
         m_Scene.setSceneRect(0, 0, 800, 480);
         m_View->setFixedSize(800, 480);
+        if (m_LabelBackground){
+            m_LabelBackground->setFixedSize(800, 480);
+            m_Proxy->setPos(0,0);
+        }
     }
     createWidgets();
 
