@@ -80,9 +80,10 @@ void LsDateTime::timerSlot()
 {
     QDateTime now = QDateTime::currentDateTime();
     QString time = QLocale().toString(now, m_TimeFormat);
-    if (time != m_TimeString){
+    QString date = QLocale().toString(now, m_DateFormat);
+    if (time != m_TimeString || date != m_DateString){
         m_TimeString = time;
-        m_DateString = QLocale().toString(now, m_DateFormat);
+        m_DateString = date;
         update();
     }
 }
